{% extends "base.html" %}

{% block title %}Page Not Found - {{ site_name() }}{% endblock %}

{% block main_class %} error-page{% endblock %}

{% block content %}
<article>
    <header>
        <h1>Page Not Found</h1>
    </header>

    <p>The page you're looking for doesn't exist or has been moved.</p>

    <footer>
        <a href="/" role="button">Return Home</a>
    </footer>
</article>
{% endblock %}
