{% extends "admin/base.html" %}

{% block title %}Admin - {{ site_name() }}{% endblock %}

{% block admin_content %}
<hgroup>
    <h1>Admin Dashboard</h1>
    <p>Welcome to the admin area</p>
</hgroup>

<section class="admin-quick-links">
    {% for item in admin_nav %}
    <a href="{{ item.path }}" class="admin-card">
        <h3>{{ item.label }}</h3>
        <p>Manage {{ item.label | lower }}</p>
    </a>
    {% endfor %}
</section>
{% endblock %}
