{% extends "setup/base.html" %}

{% block title %}Create Admin Account - Skrift{% endblock %}

{% block content %}
<h2>Create Admin Account</h2>
<p class="description">Sign in with one of your configured providers to create the first admin account.</p>

<div class="oauth-buttons">
    {% for key, provider in providers.items() %}
    <a href="/setup/oauth/{{ key }}/login" class="oauth-btn oauth-btn-{{ key }}">
        Sign in with {{ provider.name }}
    </a>
    {% endfor %}
</div>

<p style="text-align: center; margin-top: 2rem; color: var(--muted-color, #666);">
    <small>The first user to sign in will become the site administrator.</small>
</p>

<div class="form-actions" style="margin-top: 2rem;">
    <a href="/setup/site" class="btn-secondary" role="button">Back</a>
</div>
{% endblock %}
