{% extends "setup/base.html" %}

{% block title %}Site Settings - Skrift{% endblock %}

{% block content %}
<h2>Site Settings</h2>
<p class="description">Configure your site's basic information.</p>

<form method="post" action="/setup/site">
    <div class="form-group">
        <label for="site_name">Site Name *</label>
        <input type="text" id="site_name" name="site_name" value="{{ settings.site_name }}" required>
        <small>The name displayed in the header and browser title</small>
    </div>

    <div class="form-group">
        <label for="site_tagline">Site Tagline</label>
        <input type="text" id="site_tagline" name="site_tagline" value="{{ settings.site_tagline }}">
        <small>A short description or slogan for your site</small>
    </div>

    <div class="form-group">
        <label for="site_copyright_holder">Copyright Holder</label>
        <input type="text" id="site_copyright_holder" name="site_copyright_holder" value="{{ settings.site_copyright_holder }}">
        <small>Name displayed in the copyright notice (defaults to site name if empty)</small>
    </div>

    <div class="form-group">
        <label for="site_copyright_start_year">Copyright Start Year</label>
        <input type="number" id="site_copyright_start_year" name="site_copyright_start_year" value="{{ settings.site_copyright_start_year }}" min="1900" max="2100">
        <small>If different from current year, will show a range (e.g., 2020-2026)</small>
    </div>

    <div class="form-actions">
        <a href="/setup/auth" class="btn-secondary" role="button">Back</a>
        <button type="submit">Save &amp; Continue</button>
    </div>
</form>
{% endblock %}
