{% extends "base.html" %}

{% block title %}Server Error - {{ site_name() }}{% endblock %}

{% block main_class %} error-page{% endblock %}

{% block content %}
<article>
    <header>
        <h1>Server Error</h1>
    </header>

    <p>Something went wrong on our end. Please try again later.</p>

    <footer>
        <a href="/" role="button">Return Home</a>
    </footer>
</article>
{% endblock %}
